==> apigatewayv2-integrations-1.104.0-sources.jar: software/amazon/awscdk/services/apigatewayv2/integrations/HttpNlbIntegrationProps.java <==
package software.amazon.awscdk.services.apigatewayv2.integrations;

/**
 * (experimental) Properties to initialize `HttpNlbIntegration`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-05-14T22:40:31.097Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigatewayv2.integrations.$Module.class, fqn = "@aws-cdk/aws-apigatewayv2-integrations.HttpNlbIntegrationProps")
@software.amazon.jsii.Jsii.Proxy(HttpNlbIntegrationProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface HttpNlbIntegrationProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.apigatewayv2.integrations.HttpPrivateIntegrationOptions {

    /**
     * (experimental) The listener to the network load balancer used for the integration.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.elasticloadbalancingv2.INetworkListener getListener();

    /**
     * @return a {@link Builder} of {@link HttpNlbIntegrationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link HttpNlbIntegrationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<HttpNlbIntegrationProps> {
        private software.amazon.awscdk.services.elasticloadbalancingv2.INetworkListener listener;
        private software.amazon.awscdk.services.apigatewayv2.HttpMethod method;
        private software.amazon.awscdk.services.apigatewayv2.IVpcLink vpcLink;

        /**
         * Sets the value of {@link HttpNlbIntegrationProps#getListener}
         * @param listener The listener to the network load balancer used for the integration. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder listener(software.amazon.awscdk.services.elasticloadbalancingv2.INetworkListener listener) {
            this.listener = listener;
            return this;
        }

        /**
         * Sets the value of {@link HttpNlbIntegrationProps#getMethod}
         * @param method The HTTP method that must be used to invoke the underlying HTTP proxy.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder method(software.amazon.awscdk.services.apigatewayv2.HttpMethod method) {
            this.method = method;
            return this;
        }

        /**
         * Sets the value of {@link HttpNlbIntegrationProps#getVpcLink}
         * @param vpcLink The vpc link to be used for the private integration.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder vpcLink(software.amazon.awscdk.services.apigatewayv2.IVpcLink vpcLink) {
            this.vpcLink = vpcLink;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link HttpNlbIntegrationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public HttpNlbIntegrationProps build() {
            return new Jsii$Proxy(listener, method, vpcLink);
        }
    }

    /**
     * An implementation for {@link HttpNlbIntegrationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements HttpNlbIntegrationProps {
        private final software.amazon.awscdk.services.elasticloadbalancingv2.INetworkListener listener;
        private final software.amazon.awscdk.services.apigatewayv2.HttpMethod method;
        private final software.amazon.awscdk.services.apigatewayv2.IVpcLink vpcLink;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.listener = software.amazon.jsii.Kernel.get(this, "listener", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.elasticloadbalancingv2.INetworkListener.class));
            this.method = software.amazon.jsii.Kernel.get(this, "method", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigatewayv2.HttpMethod.class));
            this.vpcLink = software.amazon.jsii.Kernel.get(this, "vpcLink", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigatewayv2.IVpcLink.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.elasticloadbalancingv2.INetworkListener listener, final software.amazon.awscdk.services.apigatewayv2.HttpMethod method, final software.amazon.awscdk.services.apigatewayv2.IVpcLink vpcLink) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.listener = java.util.Objects.requireNonNull(listener, "listener is required");
            this.method = method;
            this.vpcLink = vpcLink;
        }

        @Override
        public final software.amazon.awscdk.services.elasticloadbalancingv2.INetworkListener getListener() {
            return this.listener;
        }

        @Override
        public final software.amazon.awscdk.services.apigatewayv2.HttpMethod getMethod() {
            return this.method;
        }

        @Override
        public final software.amazon.awscdk.services.apigatewayv2.IVpcLink getVpcLink() {
            return this.vpcLink;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("listener", om.valueToTree(this.getListener()));
            if (this.getMethod() != null) {
                data.set("method", om.valueToTree(this.getMethod()));
            }
            if (this.getVpcLink() != null) {
                data.set("vpcLink", om.valueToTree(this.getVpcLink()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-apigatewayv2-integrations.HttpNlbIntegrationProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            HttpNlbIntegrationProps.Jsii$Proxy that = (HttpNlbIntegrationProps.Jsii$Proxy) o;

            if (!listener.equals(that.listener)) return false;
            if (this.method != null ? !this.method.equals(that.method) : that.method != null) return false;
            return this.vpcLink != null ? this.vpcLink.equals(that.vpcLink) : that.vpcLink == null;
        }

        @Override
        public final int hashCode() {
            int result = this.listener.hashCode();
            result = 31 * result + (this.method != null ? this.method.hashCode() : 0);
            result = 31 * result + (this.vpcLink != null ? this.vpcLink.hashCode() : 0);
            return result;
        }
    }
}

==> apigatewayv2-integrations-1.204.0-sources.jar: software/amazon/awscdk/services/apigatewayv2/integrations/HttpNlbIntegrationProps.java <==
package software.amazon.awscdk.services.apigatewayv2.integrations;

/**
 * (experimental) Properties to initialize <code>HttpNlbIntegration</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.apigatewayv2.*;
 * import software.amazon.awscdk.services.apigatewayv2.integrations.*;
 * ParameterMapping parameterMapping;
 * VpcLink vpcLink;
 * HttpNlbIntegrationProps httpNlbIntegrationProps = HttpNlbIntegrationProps.builder()
 *         .method(HttpMethod.ANY)
 *         .parameterMapping(parameterMapping)
 *         .secureServerName("secureServerName")
 *         .vpcLink(vpcLink)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.84.0 (build 5404dcf)", date = "2023-06-19T16:30:45.684Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigatewayv2.integrations.$Module.class, fqn = "@aws-cdk/aws-apigatewayv2-integrations.HttpNlbIntegrationProps")
@software.amazon.jsii.Jsii.Proxy(HttpNlbIntegrationProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface HttpNlbIntegrationProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.apigatewayv2.integrations.HttpPrivateIntegrationOptions {

    /**
     * @return a {@link Builder} of {@link HttpNlbIntegrationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link HttpNlbIntegrationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<HttpNlbIntegrationProps> {
        software.amazon.awscdk.services.apigatewayv2.HttpMethod method;
        software.amazon.awscdk.services.apigatewayv2.ParameterMapping parameterMapping;
        java.lang.String secureServerName;
        software.amazon.awscdk.services.apigatewayv2.IVpcLink vpcLink;

        /**
         * Sets the value of {@link HttpNlbIntegrationProps#getMethod}
         * @param method The HTTP method that must be used to invoke the underlying HTTP proxy.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder method(software.amazon.awscdk.services.apigatewayv2.HttpMethod method) {
            this.method = method;
            return this;
        }

        /**
         * Sets the value of {@link HttpNlbIntegrationProps#getParameterMapping}
         * @param parameterMapping Specifies how to transform HTTP requests before sending them to the backend.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder parameterMapping(software.amazon.awscdk.services.apigatewayv2.ParameterMapping parameterMapping) {
            this.parameterMapping = parameterMapping;
            return this;
        }

        /**
         * Sets the value of {@link HttpNlbIntegrationProps#getSecureServerName}
         * @param secureServerName Specifies the server name to verified by HTTPS when calling the backend integration.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder secureServerName(java.lang.String secureServerName) {
            this.secureServerName = secureServerName;
            return this;
        }

        /**
         * Sets the value of {@link HttpNlbIntegrationProps#getVpcLink}
         * @param vpcLink The vpc link to be used for the private integration.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder vpcLink(software.amazon.awscdk.services.apigatewayv2.IVpcLink vpcLink) {
            this.vpcLink = vpcLink;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link HttpNlbIntegrationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public HttpNlbIntegrationProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link HttpNlbIntegrationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements HttpNlbIntegrationProps {
        private final software.amazon.awscdk.services.apigatewayv2.HttpMethod method;
        private final software.amazon.awscdk.services.apigatewayv2.ParameterMapping parameterMapping;
        private final java.lang.String secureServerName;
        private final software.amazon.awscdk.services.apigatewayv2.IVpcLink vpcLink;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.method = software.amazon.jsii.Kernel.get(this, "method", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigatewayv2.HttpMethod.class));
            this.parameterMapping = software.amazon.jsii.Kernel.get(this, "parameterMapping", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigatewayv2.ParameterMapping.class));
            this.secureServerName = software.amazon.jsii.Kernel.get(this, "secureServerName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.vpcLink = software.amazon.jsii.Kernel.get(this, "vpcLink", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigatewayv2.IVpcLink.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.method = builder.method;
            this.parameterMapping = builder.parameterMapping;
            this.secureServerName = builder.secureServerName;
            this.vpcLink = builder.vpcLink;
        }

        @Override
        public final software.amazon.awscdk.services.apigatewayv2.HttpMethod getMethod() {
            return this.method;
        }

        @Override
        public final software.amazon.awscdk.services.apigatewayv2.ParameterMapping getParameterMapping() {
            return this.parameterMapping;
        }

        @Override
        public final java.lang.String getSecureServerName() {
            return this.secureServerName;
        }

        @Override
        public final software.amazon.awscdk.services.apigatewayv2.IVpcLink getVpcLink() {
            return this.vpcLink;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getMethod() != null) {
                data.set("method", om.valueToTree(this.getMethod()));
            }
            if (this.getParameterMapping() != null) {
                data.set("parameterMapping", om.valueToTree(this.getParameterMapping()));
            }
            if (this.getSecureServerName() != null) {
                data.set("secureServerName", om.valueToTree(this.getSecureServerName()));
            }
            if (this.getVpcLink() != null) {
                data.set("vpcLink", om.valueToTree(this.getVpcLink()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-apigatewayv2-integrations.HttpNlbIntegrationProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            HttpNlbIntegrationProps.Jsii$Proxy that = (HttpNlbIntegrationProps.Jsii$Proxy) o;

            if (this.method != null ? !this.method.equals(that.method) : that.method != null) return false;
            if (this.parameterMapping != null ? !this.parameterMapping.equals(that.parameterMapping) : that.parameterMapping != null) return false;
            if (this.secureServerName != null ? !this.secureServerName.equals(that.secureServerName) : that.secureServerName != null) return false;
            return this.vpcLink != null ? this.vpcLink.equals(that.vpcLink) : that.vpcLink == null;
        }

        @Override
        public final int hashCode() {
            int result = this.method != null ? this.method.hashCode() : 0;
            result = 31 * result + (this.parameterMapping != null ? this.parameterMapping.hashCode() : 0);
            result = 31 * result + (this.secureServerName != null ? this.secureServerName.hashCode() : 0);
            result = 31 * result + (this.vpcLink != null ? this.vpcLink.hashCode() : 0);
            return result;
        }
    }
}
